
torusgrid
############
`torusgrid` is a package based on pyfftw that facilitates (periodic) field simulations.

Modules
############

`torusgrid.fields` - contains `ComplexField` and `RealField`, which are arrays with definite sizes equipped with FFT operations

`torusgrid.grids` - contains `ComplexGrid` and `RealGrid`

`torusgrid.field_util` - utility functions to manipulate `ComplexField2D` or `RealField2D` objects


